==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/igr-mask-input.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { IgrMaskInputBase } from "./igr-mask-input-base";
import { MaskInput } from "./MaskInput";
import { IgcMaskInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum } from "igniteui-react-core";
/**
 * A masked input is an input field where a developer can control user input and format the visible value,
 * based on configurable rules
*/
var IgrMaskInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrMaskInput, _super);
    function IgrMaskInput(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcMaskInputComponent);
        return _this;
    }
    IgrMaskInput.prototype.createImplementation = function () {
        return new MaskInput();
    };
    Object.defineProperty(IgrMaskInput.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrMaskInput.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        _super.prototype.componentDidMount.call(this);
    };
    IgrMaskInput.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var div = React.createElement("igc-mask-input", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    };
    IgrMaskInput.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrMaskInput.prototype, "valueMode", {
        /**
         * Dictates the behavior when retrieving the value of the control:
         * - `raw` will return the clean user input.
         * - `withFormatting` will return the value with all literals and prompts.
        */
        get: function () {
            return this.i.ae;
        },
        set: function (v) {
            this.i.ae = ensureEnum(MaskInputValueMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMaskInput.prototype, "value", {
        get: function () {
            return this.i.ag;
        },
        set: function (v) {
            this.i.ag = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMaskInput.prototype, "mask", {
        /**
         * The mask pattern to apply on the input.
        */
        get: function () {
            return this.i.af;
        },
        set: function (v) {
            this.i.af = v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Checks for validity of the control and shows the browser message if it's invalid.
    
    */
    IgrMaskInput.prototype.reportValidity = function () {
        this.i.ai();
    };
    /**
     * Check for validity of the control
    
    */
    IgrMaskInput.prototype.checkValidity = function () {
        this.i.ah();
    };
    return IgrMaskInput;
}(IgrMaskInputBase));
export { IgrMaskInput };

==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/igr-mask-input.js <==
import { __extends } from "tslib";
import * as React from 'react';
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { IgrMaskInputBase } from "./igr-mask-input-base";
import { MaskInput } from "./MaskInput";
import { IgcMaskInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum } from "igniteui-react-core";
/**
 * A masked input is an input field where a developer can control user input and format the visible value,
 * based on configurable rules
*/
var IgrMaskInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrMaskInput, _super);
    function IgrMaskInput(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcMaskInputComponent);
        return _this;
    }
    IgrMaskInput.prototype.createImplementation = function () {
        return new MaskInput();
    };
    Object.defineProperty(IgrMaskInput.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrMaskInput.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrMaskInput.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-mask-input", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    };
    IgrMaskInput.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrMaskInput.prototype, "valueMode", {
        /**
         * Dictates the behavior when retrieving the value of the control:
         * - `raw` will return the clean user input.
         * - `withFormatting` will return the value with all literals and prompts.
        */
        get: function () {
            return this.i.af;
        },
        set: function (v) {
            this.i.af = ensureEnum(MaskInputValueMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMaskInput.prototype, "value", {
        get: function () {
            return this.i.ah;
        },
        set: function (v) {
            this.i.ah = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMaskInput.prototype, "mask", {
        /**
         * The mask pattern to apply on the input.
        */
        get: function () {
            return this.i.ag;
        },
        set: function (v) {
            this.i.ag = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrMaskInput.prototype.connectedCallback = function () {
        this.i.ai();
    };
    return IgrMaskInput;
}(IgrMaskInputBase));
export { IgrMaskInput };
